skhubness.neighbors.BallTree
============================

.. currentmodule:: skhubness.neighbors

.. autoclass:: BallTree

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BallTree.__init__
      ~BallTree.get_arrays
      ~BallTree.get_n_calls
      ~BallTree.get_tree_stats
      ~BallTree.kernel_density
      ~BallTree.query
      ~BallTree.query_radius
      ~BallTree.reset_n_calls
      ~BallTree.two_point_correlation
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~BallTree.data
      ~BallTree.idx_array
      ~BallTree.node_bounds
      ~BallTree.node_data
      ~BallTree.sample_weight
      ~BallTree.sum_weight
      ~BallTree.valid_metrics
   
   